@@ -3,8 +3,7 @@
 /*      asmail - AfterStep Mail                                              */
 /*                                                                           */
 /*      By Per Liden                                                         */
-/*      per@oden.rsn.hk-r.se                                                 */
-/*      http://oden.rsn.hk-r.se/~per                                         */
+/*      Last changed Feb 17. 2000 by Martin Domig                            */
 /*                                                                           */
 /*****************************************************************************/
 
@@ -128,8 +127,8 @@ int AnimationSpeed[3] =
  DEFANIMATIONSPEED};
 char HelpMessage[] =
 {
-    "asmail - Version 0.52.1, by Per Liden (per@oden.rsn.hk-r.se)\n"
-    "usage:  asmail [file] [options ...] \n"
+    "asmail - Version 0.55, by Per Liden\n"
+    "usage:  asmail [file] [options ...]\n"
     "file:\n"
     "        configuration file to use (default ~/.asmailrc)\n"
     "options:\n"
@@ -280,7 +279,7 @@ void shorten(char *line)
     if (line[strlen(line)-1] == '\n')
         line[strlen(line)-1] = '\0';
     
-    while (isblank(line[i]) && line[i]) i++;
+    while (isspace(line[i]) && line[i]) i++;
     if (i == 0 || i == strlen(line))
         return;
     while (line[i])
@@ -288,7 +287,7 @@ void shorten(char *line)
     line[j] = '\0';
     
     i = strlen(line);
-    while (isblank(line[i]) && i > 0) i--;
+    while (isspace(line[i]) && i > 0) i--;
     if (line[i] == '\n') i--;
     line[++i] = '\0';
 }
@@ -760,8 +759,9 @@ void SetAnimTimeout(void)
 void StartLoop(void)
 {
     /* Check mailbox at statup */
-    if (CheckMailBox(MailBoxes, NumOfMailBoxes))
-	   RedrawWindow();
+    /* if (CheckMailBox(MailBoxes, NumOfMailBoxes))
+	 *   RedrawWindow();
+	 */
 
     /* Set timeout */
     XtAppAddTimeOut(AsmailApp, (unsigned long) (Interval * 1000),
